Class: RandomPerson::Names::EnglishLast

Inherits:
RandomPerson::Name show all
Defined in:
lib/randomperson/names/english-last.rb

Constant Summary collapse

Names =
%w{ Smith Brown Taylor Johnson Walker Wright Robinson Thompson White Green Hall Wood Harris Martin Jackson Clarke Clark Turner Hill Cooper Ward Moore King Watson Baker Harrison Young Allen Mitchell Anderson Lee Bell Parker Davis Bennett Miller Cook Shaw Richardson Carter Collins Marshall Bailey Gray Cox Adams Wilkinson Foster Chapman Mason Russell Webb Rogers Hunt Mills Holmes Palmer Matthews Fisher Barnes Knight Harvey Barker Butler Jenkins Stevens Pearson Dixon Fletcher Hunter Howard Andrews Reynolds Elliott Fox Ford Saunders Payne West Day Pearce Brooks Bradley Dawson Walsh Lawrence Cole Atkinson Ball Spencer Armstrong Burton Booth Rose Webster Williamson Watts Hart Burns Wells }

Instance Attribute Summary

Attributes inherited from RandomPerson::Name

#formats, #formats_ratiod, #names, #possibles

Instance Method Summary collapse

Methods included from Outputter

included

Constructor Details

#initializeEnglishLast

Returns a new instance of EnglishLast.



10
11
12
13
14
15
16
17
18
# File 'lib/randomperson/names/english-last.rb', line 10

def initialize
  @names = Names
  @formats = [
    ->(n)   { n.sample },
    ->(n)   { n.sample + '-' + n.sample },
   ]
  @formats_ratiod = [ 0..96, 97..99 ]
  super
end